// generated from rosidl_adapter/resource/msg.idl.em
// with input from nav_msgs/msg/MapMetaData.msg
// generated code does not contain a copyright notice

#include "builtin_interfaces/msg/Time.idl"
#include "geometry_msgs/msg/Pose.idl"

module nav_msgs {
  module msg {
    @verbatim (language="comment", text=
      "This hold basic information about the characteristics of the OccupancyGrid")
    struct MapMetaData {
      @verbatim (language="comment", text=
        "The time at which the map was loaded")
      builtin_interfaces::msg::Time map_load_time;

      @verbatim (language="comment", text=
        "The map resolution")
      @unit (value="m/cell")
      float resolution;

      @verbatim (language="comment", text=
        "Map width")
      @unit (value="cells")
      uint32 width;

      @verbatim (language="comment", text=
        "Map height")
      @unit (value="cells")
      uint32 height;

      @verbatim (language="comment", text=
        "The origin of the map [m, m, rad].  This is the real-world pose of the" "\n"
        "bottom left corner of cell (0,0) in the map.")
      geometry_msgs::msg::Pose origin;
    };
  };
};
