// generated from rosidl_adapter/resource/msg.idl.em
// with input from nav_msgs/msg/Path.msg
// generated code does not contain a copyright notice

#include "geometry_msgs/msg/PoseStamped.idl"
#include "std_msgs/msg/Header.idl"

module nav_msgs {
  module msg {
    @verbatim (language="comment", text=
      "An array of poses that represents a Path for a robot to follow.")
    struct Path {
      @verbatim (language="comment", text=
        "Indicates the frame_id of the path.")
      std_msgs::msg::Header header;

      @verbatim (language="comment", text=
        "Array of poses to follow.")
      sequence<geometry_msgs::msg::PoseStamped> poses;
    };
  };
};
